unit getspecu;

// Copyright  1999 by Ziff-Davis, Inc.
// Written by Neil J. Rubenking

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls;

type
  TSpecForm = class(TForm)
    ebSpec    : TEdit;
    Bevel1    : TBevel;
    lblStat   : TLabel;
    btnOK     : TButton;
    btnCancel : TButton;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ebSpecKeyPress(Sender: TObject; var Key: Char);
    procedure ebSpecChange(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    procedure SetSpec(const S : String);
    function GetSpec : String;
  end;

var
  SpecForm: TSpecForm;

implementation

uses allfuncs;

{$R *.DFM}

procedure TSpecForm.FormCreate(Sender: TObject);
begin
  GetPosFmEXEName(Application.ExeName, Self, False);
end;

procedure TSpecForm.FormDestroy(Sender: TObject);
begin
  SetPosToEXEName(Application.ExeName, Self, False);
end;

function TSpecForm.GetSpec: String;
begin
  Result := ebSpec.Text;
end;

procedure TSpecForm.SetSpec(const S: String);
begin
  ebSpec.Text := S;
  btnOK.Enabled := (Pos('.', ebSpec.Text) > 1) AND
    (Length(ebSpec.Text) > 1);
end;

procedure TSpecForm.ebSpecKeyPress(Sender: TObject; var Key: Char);
begin
  CASE Key OF
    // Don't accept chars that are invalid in a filespec
    '"',':','<','>','|','\','/' : Key := #0;
  END;
end;

procedure TSpecForm.ebSpecChange(Sender: TObject);
VAR
  Sn, Se : String;
  N : Integer;
begin
  // Deal with pasted-in text that contains invalid chars
  Sn := (Sender AS TEdit).Text;
  FOR N := length(Sn) DOWNTO 1 DO
    CASE Sn[N] OF
      '"',':','<','>','|','\','/' : Delete(Sn, N, 1);
    END;
  IF Sn <> (Sender AS TEdit).Text THEN
    begin
      (Sender AS TEdit).Text     := Sn;
      (Sender AS TEdit).SelStart := length(Sn);
    end;
  N := LastDelimiter('.', Sn);
  IF N = 0 THEN Se := ''
  ELSE
    begin
      Se := Copy(Sn, N+1, Length(Sn)-N);
      SetLength(Sn, N-1);
    end;
  IF Sn = '' THEN
    lblStat.Caption := 'Must enter filename'
  ELSE IF Pos('.', ebSpec.Text) = 0 THEN
    lblStat.Caption := 'Must enter extension (or period)'
  ELSE IF Se = '' THEN
    lblStat.Caption := 'Note: Only matches files with no extension'
  ELSE IF Length(Se) > 3 THEN
    lblStat.Caption := 'Note: Extension longer than 3 letters'
  ELSE IF (Se = '*') AND (Sn = '*') THEN
    lblStat.Caption := 'Warning: Matches all files!'
  ELSE IF (pos('*', Se) > 0) AND
          (pos('*', Sn) > 0) THEN
    lblStat.Caption := 'Warning: * in both name and extension'
  ELSE IF (pos('*', Se)  = 0) AND
          (pos('*', Sn) = 0) AND
          (pos('?', Se)  = 0) AND
          (pos('?', Sn) = 0) THEN
    lblStat.Caption := Format('Note: Matches exact filename '+
      'only', [Sn, Se])
  ELSE lblStat.Caption := '';
  btnOK.Enabled := (Pos('.', ebSpec.Text) > 1) AND
    (Length(ebSpec.Text) > 1);
end;

end.
